print("""

  Do not answer!

  Do not answer!!

  Do not answer!!!

  This world has received your message.

  I am a pacifist in this world. It is the luck of your civilization that I am the first to receive your message. I am warning you: Do not answer! Do not answer!! Do not answer!!!

  There are tens of millions of stars in your direction. As long as you do not answer, this world will not be able to ascertain the source of your transmission.

  But if you do answer, the source will be located right away. Your planet will be invaded. Your world will be conquered!

  Do not answer! Do not answer!! Do not answer!!!
  
  
  --- 'Three Body Problem'

  This boring package is made by JackM
  
  """)




import setuptools
with open("README.md", "r") as fh:
    long_description = fh.read()
setuptools.setup(
     name='mydream',  
     version='0.3.1',
     author="Jack Ma",
     script="mydream",
     author_email="924756831@qq.com",
     description="A man made Easter-Egg",
     long_description=long_description,
   long_description_content_type="text/markdown",
     url="https://github.com/kingjacM",
     packages=["mydream"],
     classifiers=[
         "Programming Language :: Python :: 3",
         "License :: OSI Approved :: MIT License",
         "Operating System :: OS Independent",
     ],


 )